@@ -102,13 +102,12 @@ class Firewall(object):
         self.__init_vars()
 
     def __repr__(self):
-        return '%s(%r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r)' % \
+        return '%s(%r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r)' % \
             (self.__class__, self.ip4tables_enabled, self.ip6tables_enabled,
              self.ebtables_enabled, self._state, self._panic,
              self._default_zone, self._module_refcount, self._marks,
              self.cleanup_on_exit, self.ipv6_rpfilter_enabled,
-             self.ipset_enabled, self._individual_calls, self._log_denied,
-             self._automatic_helpers)
+             self.ipset_enabled, self._individual_calls, self._log_denied)
 
     def __init_vars(self):
         self._state = "INIT"
@@ -121,13 +120,9 @@ class Firewall(object):
         self.ipv6_rpfilter_enabled = config.FALLBACK_IPV6_RPFILTER
         self._individual_calls = config.FALLBACK_INDIVIDUAL_CALLS
         self._log_denied = config.FALLBACK_LOG_DENIED
-        self._automatic_helpers = config.FALLBACK_AUTOMATIC_HELPERS
         self._firewall_backend = config.FALLBACK_FIREWALL_BACKEND
         self._flush_all_on_reload = config.FALLBACK_FLUSH_ALL_ON_RELOAD
         self._rfc3964_ipv4 = config.FALLBACK_RFC3964_IPV4
-        self.nf_conntrack_helper_setting = 0
-        self.nf_conntrack_helpers = { }
-        self.nf_nat_helpers = { }
 
     def individual_calls(self):
         return self._individual_calls
@@ -210,28 +205,6 @@ class Firewall(object):
             log.debug1("ebtables-restore is not supporting the --noflush "
                        "option, will therefore not be used")
 
-        if os.path.exists(config.COMMANDS["modinfo"]):
-            self.nf_conntrack_helpers = functions.get_nf_conntrack_helpers()
-            if len(self.nf_conntrack_helpers) > 0:
-                log.debug1("Conntrack helpers supported by the kernel:")
-                for key,values in self.nf_conntrack_helpers.items():
-                    log.debug1("  %s: %s", key, ", ".join(values))
-            else:
-                log.debug1("No conntrack helpers supported by the kernel.")
-
-            self.nf_nat_helpers = functions.get_nf_nat_helpers()
-            if len(self.nf_nat_helpers) > 0:
-                log.debug1("NAT helpers supported by the kernel:")
-                for key,values in self.nf_nat_helpers.items():
-                    log.debug1("  %s: %s", key, ", ".join(values))
-            else:
-                log.debug1("No NAT helpers supported by the kernel.")
-
-        else:
-            self.nf_conntrack_helpers = { }
-            self.nf_nat_helpers = { }
-            log.warning("modinfo command is missing, not able to detect conntrack helpers.")
-
     def _start(self, reload=False, complete_reload=False):
         # initialize firewall
         default_zone = config.FALLBACK_ZONE
@@ -290,18 +263,6 @@ class Firewall(object):
                     self._log_denied = value.lower()
                     log.debug1("LogDenied is set to '%s'", self._log_denied)
 
-            if self._firewalld_conf.get("AutomaticHelpers"):
-                value = self._firewalld_conf.get("AutomaticHelpers")
-                if value is not None:
-                    if value.lower() in [ "no", "false" ]:
-                        self._automatic_helpers = "no"
-                    elif value.lower() in [ "yes", "true" ]:
-                        self._automatic_helpers = "yes"
-                    else:
-                        self._automatic_helpers = value.lower()
-                    log.debug1("AutomaticHelpers is set to '%s'",
-                               self._automatic_helpers)
-
             if self._firewalld_conf.get("FirewallBackend"):
                 self._firewall_backend = self._firewalld_conf.get("FirewallBackend")
                 log.debug1("FirewallBackend is set to '%s'",
@@ -419,19 +380,6 @@ class Firewall(object):
         if self._offline:
             return
 
-        # automatic helpers
-        #
-        # NOTE: must force loading of nf_conntrack to make sure the values are
-        # available in /proc
-        module_return = self.handle_modules(["nf_conntrack"], True)
-        if module_return:
-            log.error("Failed to load nf_conntrack module: %s" % module_return[1])
-            sys.exit(1)
-        if self._automatic_helpers != "system":
-            functions.set_nf_conntrack_helper_setting(self._automatic_helpers == "yes")
-        self.nf_conntrack_helper_setting = \
-            functions.get_nf_conntrack_helper_setting()
-
         # check if needed tables are there
         self._check_tables()
 
@@ -688,6 +636,8 @@ class Firewall(object):
     # handle modules
 
     def handle_modules(self, _modules, enable):
+        num_failed = 0
+        error_msgs = ""
         for i,module in enumerate(_modules):
             if enable:
                 (status, msg) = self.modules_backend.load_module(module)
@@ -697,9 +647,9 @@ class Firewall(object):
                 else:
                     (status, msg) = self.modules_backend.unload_module(module)
             if status != 0:
-                if enable:
-                    return (_modules[:i], msg) # cleanup modules and error msg
-                # else: ignore cleanup
+                num_failed += 1
+                error_msgs += msg
+                continue
 
             if enable:
                 self._module_refcount.setdefault(module, 0)
@@ -709,7 +659,7 @@ class Firewall(object):
                     self._module_refcount[module] -= 1
                     if self._module_refcount[module] == 0:
                         del self._module_refcount[module]
-        return None
+        return (num_failed, error_msgs)
 
     def _select_firewall_backend(self, backend):
         if backend != "nftables":
@@ -823,12 +773,6 @@ class Firewall(object):
                     transaction.add_rules(ipv6_backend, rules)
 
         if self.is_ipv_enabled("ipv6") and self._rfc3964_ipv4:
-            # Flush due to iptables-restore (nftables) bug triggered when
-            # specifying same index multiple times in same batch
-            # rhbz 1647925
-            transaction.execute(True)
-            transaction.clear()
-
             rules = ipv6_backend.build_rfc3964_ipv4_rules()
             transaction.add_rules(ipv6_backend, rules)
 
@@ -892,7 +836,7 @@ class Firewall(object):
                                 "'%s' is not a valid backend" % backend_name)
 
         if not self.is_backend_enabled(backend_name):
-            return ""
+            return
 
         if self._individual_calls or \
            not backend.restore_command_exists or \
@@ -910,9 +854,8 @@ class Firewall(object):
                             # ignore errors here
                             pass
                     raise msg
-            return True
         else:
-            return backend.set_rules(_rules, self._log_denied)
+            backend.set_rules(_rules, self._log_denied)
 
     # check functions
 
@@ -1107,24 +1050,6 @@ class Firewall(object):
         else:
             raise FirewallError(errors.ALREADY_SET, value)
 
-    # AUTOMATIC HELPERS
-
-    def get_automatic_helpers(self):
-        return self._automatic_helpers
-
-    def set_automatic_helpers(self, value):
-        if value not in config.AUTOMATIC_HELPERS_VALUES:
-            raise FirewallError(errors.INVALID_VALUE,
-                                "'%s', choose from '%s'" % \
-                                (value, "','".join(config.AUTOMATIC_HELPERS_VALUES)))
-
-        if value != self.get_automatic_helpers():
-            self._automatic_helpers = value
-            self._firewalld_conf.set("AutomaticHelpers", value)
-            self._firewalld_conf.write()
-        else:
-            raise FirewallError(errors.ALREADY_SET, value)
-
     # DEFAULT ZONE
 
     def get_default_zone(self):
