@@ -62,14 +62,6 @@ class FirewallIPSet(object):
             self.check_applied_obj(obj)
         return obj
 
-    def _error2warning(self, f, name, *args):
-        # transform errors into warnings
-        try:
-            f(name, *args)
-        except FirewallError as error:
-            msg = str(error)
-            log.warning("%s: %s" % (name, msg))
-
     def backends(self):
         backends = []
         if self._fw.nftables_enabled:
@@ -117,8 +109,7 @@ class FirewallIPSet(object):
                         except Exception as msg:
                             raise FirewallError(errors.COMMAND_FAILED, msg)
 
-                if self._fw.individual_calls() \
-                   or backend.name == "nftables":
+                if self._fw.individual_calls():
                     try:
                         backend.set_create(obj.name, obj.type, obj.options)
                     except Exception as msg:
@@ -174,12 +165,6 @@ class FirewallIPSet(object):
 
     # ENTRIES
 
-    def __entry_id(self, entry):
-        return entry
-
-    def __entry(self, enable, name, entry):
-        pass
-
     def add_entry(self, name, entry):
         obj = self.get_ipset(name, applied=True)
 
@@ -248,8 +233,7 @@ class FirewallIPSet(object):
 
         try:
             for backend in self.backends():
-                if self._fw.individual_calls() \
-                   or backend.name == "nftables":
+                if self._fw.individual_calls():
                     for entry in obj.entries:
                         backend.set_add(obj.name, entry)
                 else:
